#!/usr/bin/env python
#
# Copyright Dowell Research
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0


__version__ = "0.1.0"
